GlobalCpuState

Struct GlobalCpuState 

#[repr(align(64))]
pub struct GlobalCpuState { idt: UncheckedCell<InterruptDescriptorTable>, user_code_selector: AtomicU16, user_data_selector: AtomicU16, }
Global CPU state such as IDT and user code/data selectors

Fields

idt: UncheckedCell<InterruptDescriptorTable>user_code_selector: AtomicU16user_data_selector: AtomicU16

Implementations

Source

impl GlobalCpuState

pub const fn new() -> Self

Constructor; returns a GlobalCpuState with an uninitialized IDT and zeroed selectors

pub unsafe fn init_idt(&'static self)

Initialize the IDT

Safety

The caller must guarantee the following:

  • That this method has never been called before and will never be called again
  • That at the time of calling this method, no references or pointers to this data exist
  • While this method is being called, no other CPU is working with the given data
pub fn set_user_selectors(&self, code: u16, data: u16)

Set the user data and code selectors

pub unsafe fn idt(&self) -> &InterruptDescriptorTable

Getter for GlobalCpuState::Idt

Safety

The caller must guarantee the following:

  • That this value’s init method has already been called before
  • That at this method’s entire execution time, no mutable references or pointers to this data exist or will exist
pub fn user_code_selector(&self) -> u16

Getter for GlobalCpuState::user_code_selector

pub fn user_data_selector(&self) -> u16

Getter for GlobalCpuState::user_data_selector